# FundingV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV20**](CreatedDateV20.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV20**](LastModifiedDateV20.md) |  | [optional] 
**source** | [**SourceV20**](SourceV20.md) |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 
**type** | **str** |  | 
**organization_defined_type** | [**OrganizationDefinedFundingSubTypeV20**](OrganizationDefinedFundingSubTypeV20.md) |  | [optional] 
**title** | [**FundingTitleV20**](FundingTitleV20.md) |  | 
**short_description** | **str** |  | [optional] 
**amount** | [**AmountV20**](AmountV20.md) |  | [optional] 
**url** | [**UrlV20**](UrlV20.md) |  | [optional] 
**start_date** | [**FuzzyDateV20**](FuzzyDateV20.md) |  | [optional] 
**end_date** | [**FuzzyDateV20**](FuzzyDateV20.md) |  | [optional] 
**external_ids** | [**ExternalIDsV20**](ExternalIDsV20.md) |  | [optional] 
**contributors** | [**FundingContributorsV20**](FundingContributorsV20.md) |  | [optional] 
**organization** | [**OrganizationV20**](OrganizationV20.md) |  | 
**visibility** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

